summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/build.c
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/build.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/build.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/kexi/3rdparty/kexisql3/src/build.c b/kexi/3rdparty/kexisql3/src/build.c
index 67ed7975..429213da 100644
--- a/kexi/3rdparty/kexisql3/src/build.c
+++ b/kexi/3rdparty/kexisql3/src/build.c
@@ -746,7 +746,7 @@ void sqlite3StartTable(
/* Begin generating the code that will insert the table record into
** the SQLITE_MASTER table. Note in particular that we must go ahead
** and allocate the record number for the table entry now. Before any
** PRIMARY KEY or UNITQUE keywords are parsed. Those keywords will cause
** indices to be created and the table record must come before the
** indices. Hence, the record number for the table must be allocated
** now.
@@ -2011,7 +2011,7 @@ static void sqlite3RefillIndex(Parse *pParse, Index *pIndex, int memRootPage){
** Create a new index for an SQL table. pName1.pName2 is the name of the index
** and pTblList is the name of the table that is to be indexed. Both will
** be NULL for a primary key or an index that is created to satisfy a
** UNITQUE constraint. If pTable and pIndex are NULL, use pParse->pNewTable
** as the table to be indexed. pParse->pNewTable is a table that is
** currently being constructed by a CREATE TABLE statement.
**
@@ -2104,7 +2104,7 @@ void sqlite3CreateIndex(
** index, then we will continue to process this index.
**
** If pName==0 it means that we are
** dealing with a primary key or UNITQUE constraint. We have to invent our
** own name.
*/
if( pName ){
@@ -2211,12 +2211,12 @@ void sqlite3CreateIndex(
if( pTab==pParse->pNewTable ){
/* This routine has been called to create an automatic index as a
** result of a PRIMARY KEY or UNITQUE clause on a column definition, or
** a PRIMARY KEY or UNITQUE clause following the column definitions.
** i.e. one of:
**
** CREATE TABLE t(x PRIMARY KEY, y);
- ** CREATE TABLE t(x, y, UNITQUE(x, y));
+ ** CREATE TABLE t(x, y, UNIQUE(x, y));
**
** Either way, check to see if the table already has such an index. If
** so, don't bother creating this one. This only applies to
@@ -2285,7 +2285,7 @@ void sqlite3CreateIndex(
** we don't want to recreate it.
**
** If pTblName==0 it means this index is generated as a primary key
** or UNITQUE constraint of a CREATE TABLE statement. Since the table
** has just been created, it contains no data and the index initialization
** step can be skipped.
*/
@@ -2309,11 +2309,11 @@ void sqlite3CreateIndex(
if( pStart && pEnd ){
/* A named index with an explicit CREATE INDEX statement */
zStmt = sqlite3MPrintf("CREATE%s INDEX %.*s",
- onError==OE_None ? "" : " UNITQUE",
+ onError==OE_None ? "" : " UNIQUE",
pEnd->z - pName->z + 1,
pName->z);
}else{
- /* An automatic index created by a PRIMARY KEY or UNITQUE constraint */
+ /* An automatic index created by a PRIMARY KEY or UNIQUE constraint */
/* zStmt = sqlite3MPrintf(""); */
zStmt = 0;
}
@@ -2428,7 +2428,7 @@ void sqlite3DropIndex(Parse *pParse, SrcList *pName){
goto exit_drop_index;
}
if( pIndex->autoIndex ){
- sqlite3ErrorMsg(pParse, "index associated with UNITQUE "
+ sqlite3ErrorMsg(pParse, "index associated with UNIQUE "
"or PRIMARY KEY constraint cannot be dropped", 0);
goto exit_drop_index;
}
@@ -746,7 +746,7 @@ void sqlite3StartTable(
** the SQLITE_MASTER table. Note in particular that we must go ahead
** and allocate the record number for the table entry now. Before any
- ** PRIMARY KEY or UNITQUE keywords are parsed. Those keywords will cause
+ ** PRIMARY KEY or UNIQUE keywords are parsed. Those keywords will cause
** indices to be created and the table record must come before the
** indices. Hence, the record number for the table must be allocated
@@ -2011,7 +2011,7 @@ static void sqlite3RefillIndex(Parse *pParse, Index *pIndex, int memRootPage){
** and pTblList is the name of the table that is to be indexed. Both will
** be NULL for a primary key or an index that is created to satisfy a
-** UNITQUE constraint. If pTable and pIndex are NULL, use pParse->pNewTable
+** UNIQUE constraint. If pTable and pIndex are NULL, use pParse->pNewTable
** as the table to be indexed. pParse->pNewTable is a table that is
** currently being constructed by a CREATE TABLE statement.
@@ -2104,7 +2104,7 @@ void sqlite3CreateIndex(
**
** If pName==0 it means that we are
- ** dealing with a primary key or UNITQUE constraint. We have to invent our
+ ** dealing with a primary key or UNIQUE constraint. We have to invent our
** own name.
*/
@@ -2211,12 +2211,12 @@ void sqlite3CreateIndex(
if( pTab==pParse->pNewTable ){
/* This routine has been called to create an automatic index as a
- ** result of a PRIMARY KEY or UNITQUE clause on a column definition, or
- ** a PRIMARY KEY or UNITQUE clause following the column definitions.
+ ** result of a PRIMARY KEY or UNIQUE clause on a column definition, or
+ ** a PRIMARY KEY or UNIQUE clause following the column definitions.
** i.e. one of:
**
@@ -2285,7 +2285,7 @@ void sqlite3CreateIndex(
**
** If pTblName==0 it means this index is generated as a primary key
- ** or UNITQUE constraint of a CREATE TABLE statement. Since the table
+ ** or UNIQUE constraint of a CREATE TABLE statement. Since the table
** has just been created, it contains no data and the index initialization
** step can be skipped.